diff --git a/.changeset/pretty-radios-eat.md b/.changeset/pretty-radios-eat.md
new file mode 100644
index 0000000..c212470
--- /dev/null
+++ b/.changeset/pretty-radios-eat.md
@@ -0,0 +1,5 @@
+---
+"@openfun/cunningham-react": patch
+---
+
+Fixed development warning in `CalendarAux` component
diff --git a/packages/react/src/components/Forms/DatePicker/Calendar.tsx b/packages/react/src/components/Forms/DatePicker/Calendar.tsx
index 70330e2..f34fda7 100644
--- a/packages/react/src/components/Forms/DatePicker/Calendar.tsx
+++ b/packages/react/src/components/Forms/DatePicker/Calendar.tsx
@@ -174,16 +174,18 @@ const CalendarAux = forwardRef(
const downshiftMonth = useDownshiftSelect("month", monthItems);
const downshiftYear = useDownshiftSelect("year", yearItems);
// isDisabled and onPress props don't exist on the component.
// remove them to avoid any warning.
const {
isDisabled: isPrevButtonDisabled,
onPress: onPressPrev,
+ onFocusChange: onFocusChangePrev,
...prevButtonOtherProps
} = prevButtonProps;
const {
isDisabled: isNextButtonDisabled,
onPress: onPressNext,
+ onFocusChange: onFocusChangeNext,
...nextButtonOtherProps
} = nextButtonProps;
@@ -174,16 +174,18 @@ const CalendarAux = forwardRef(
const downshiftMonth = useDownshiftSelect("month", monthItems);
const downshiftYear = useDownshiftSelect("year", yearItems);
- // isDisabled and onPress props don't exist on the component.
+ // isDisabled, onPress and onFocusChange props don't exist on the component.
// remove them to avoid any warning.
const {